
/* Chrysalide - Outil d'analyse de fichiers binaires
 * dockable.c - équivalent Python du fichier "gtkext/gtkdockable.c"
 *
 * Copyright (C) 2018-2019 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "dockable.h"


#include <pygobject.h>


#include <gtkext/gtkdockable.h>


#include "../access.h"
#include "../helpers.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

PyTypeObject *get_python_gtk_dockable_type(void)
{
    static PyMethodDef py_gtk_dockable_methods[] = {
        { NULL }
    };

    static PyGetSetDef py_gtk_dockable_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_gtk_dockable_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.gtkext.GtkDockable",
        //.tp_basicsize   = sizeof(PyGObject),

        .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,

        .tp_doc         = "PyChrysalide interface for Gtk dockable widgets",

        .tp_methods     = py_gtk_dockable_methods,
        .tp_getset      = py_gtk_dockable_getseters,

    };

    return &py_gtk_dockable_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.gtkext.GtkDockable'.   *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool ensure_python_gtk_dockable_is_registered(void)
{
    PyTypeObject *type;                     /* Type Python 'GtkDockable'   */
    PyObject *module;                       /* Module à recompléter        */
    PyObject *dict;                         /* Dictionnaire du module      */

    type = get_python_gtk_dockable_type();

    if (!PyType_HasFeature(type, Py_TPFLAGS_READY))
    {
        module = get_access_to_python_module("pychrysalide.gtkext");

        dict = PyModule_GetDict(module);

        if (!register_interface_for_pygobject(dict, GTK_TYPE_DOCKABLE, type))
            return false;

    }

    return true;

}
